/*
 * signal-event.h
 */
#ifndef SIGNAL_EVENT_H_
#define SIGNAL_EVENT_H_

typedef void (*sigeventcallback_t)(int signo, siginfo_t *si, void *opaque);
		
/* sigevent_init is called when all signal handlers were added or ignored */
int sigevent_init();

/* deinitialize signal events */
void sigevent_deinit();

/* returns file descriptor to poll for POLLIN event */
int sigevent_fd();

/* runs signal handlers */
void sigevent_run();

/* sigevent_add - add signal hanlder
 * signo: signal number
 * callback: handler callback
 * opaque: opaque pointer passed to callback
 * no_delay: run handler immediately
 *
 * Returns 0 on success -1 on failure.
 */
int sigevent_add(int signo, sigeventcallback_t callback, void *opaque, int no_delay);

/* sigevent_del - delete signal handler
 * signo: signal number
 * callback: handler callback
 * opaque: opaque pointer passed to callback
 *
 * Returns 0 on success -1 on failure.
 */
int sigevent_del(int signo, sigeventcallback_t callback, void *opaque);

/* sigevent_ignore - ignore signal
 * signo: signal number
 *
 * Returns 0 on success -1 on failure.
 */
int sigevent_ignore(int signo);

#endif
